package com.zskk.dicom.monitor.queue;

import com.zskk.dicom.monitor.config.Configs;

import java.util.ArrayList;
import java.util.List;

/**
 * 队列基类
 */
public abstract class BaseQueue<T> implements IQueue<T>{

    /**
     * 承载队列数据的集合
     */
    private List<T> queue = null;

    /**
     * 队列名称
     */
    private String queueName = null;

    public BaseQueue(String queueName) {
        this.queueName = queueName;
    }

    @Override
    public int size() {
        checkSecurity();
        return this.queue.size();
    }

    @Override
    public synchronized T pop() {
        checkSecurity();
        if(size() == 0) {
            return null;
        }
        return this.queue.remove(0);
    }

    @Override
    public T peek() {
        checkSecurity();
        if(size() == 0) {
            return null;
        }
        return this.queue.get(0);
    }

    @Override
    public synchronized boolean push(T t) {
        checkSecurity();
        if(this.queue.contains(t)) {
            return false;
        }
        return this.queue.add(t);
    }

    @Override
    public boolean empty() {
        return this.queue == null || this.queue.size() == 0;
    }

    @Override
    public void init() {
        Configs.sysLog.info("the queue \t: " + getQueueName() + "\t is init");
        if(this.queue != null) {
            this.queue.clear();
        }
        this.queue = new ArrayList<T>();
    }

    @Override
    public void destroy() {
        Configs.sysLog.info("the queue \t: " + getQueueName() + "\t is destroy");
        if(this.queue != null) {
            this.queue.clear();
            this.queue = null;
        }
    }

    /**
     * 安全校验 队列arraylist是否被初始化
     */
    private void checkSecurity() {
        if(this.queue == null) {
            Configs.sysLog.error("queue error：" + this.queueName+ "\t queue is null");
            throw new Error("队列:" + this.queueName + "没有被初始化");
        }
    }
}
