package com.zskk.dicom.monitor.runner;

import com.zskk.dicom.monitor.config.Configs;
import com.zskk.dicom.monitor.queue.IQueue;
import org.apache.commons.io.FileUtils;
import org.apache.http.util.TextUtils;

import java.io.File;
import java.util.Iterator;

/**
 * 把遗留文件(上传或重试)添加入队列的runner基类
 */
public abstract class BaseAddHistory2QueueRunner implements Runnable {
    /**
     * 监听目录路径
     */
    private String monitorDir = null;

    /**
     * 匹配后缀数组
     */
    private String[] suffixs = null;

    /**
     * 加入的队列
     */
    private IQueue<String> queue = null;

    public BaseAddHistory2QueueRunner(String monitorDir, IQueue<String> queue) {
        this(monitorDir, queue,  TextUtils.isEmpty(Configs.suffix) ? null: new String[]{Configs.suffix});
    }

    public BaseAddHistory2QueueRunner(String monitorDir, IQueue<String> queue, String[] suffixs) {
        this.monitorDir = monitorDir;
        this.queue = queue;
        this.suffixs = suffixs;
    }

    @Override
    public void run() {
        addHistory2Queue();
    }

    /**
     * 把文件添加入队列
     */
    private void addHistory2Queue() {
        Configs.sysLog.info("BaseAddHistory2QueueRunner: init Dir:" + this.monitorDir + "start");
        File dir = new File(this.monitorDir);
        Iterator<File> its = FileUtils.iterateFiles(dir, this.suffixs, true);
        while (its.hasNext()) {
            if(Configs.poolsStartingFlag) {
                Configs.sysLog.warn("pools restart return");
                return;
            }
            File file = its.next();
            if(file.exists() && file.isFile()) {
                queue.push(file.getAbsolutePath());
            }
        }
        Configs.sysLog.info("BaseAddHistory2QueueRunner: init Dir:" + this.monitorDir + "end queue.siez:\t" + this.queue.size());
    }
}