package com.zskk.dicom.monitor.utils;

import com.zskk.dicom.monitor.config.Configs;
import org.apache.http.util.TextUtils;

import java.io.File;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

public class MonitorFileUtils {

	/**
	 * 创建一些文件夹
	 * @param dirs 文件夹路径数组
	 * @return
	 */
	public static boolean createDirs(String[] dirs) {
		boolean flag = true;
		for (String dir : dirs) {
			if(!createDir(dir)) {
				flag = false;
			}
		}
		return flag;
	}

	/**
	 * 创建文件夹
	 * @param dir 文件夹路径
	 * @return
	 */
	public static boolean createDir(String dir) {
		if(TextUtils.isEmpty(dir)) {
			return false;
		}
		File file = new File(dir);
		if(!file.exists()) {
			return file.mkdirs();
		}
		return true;
	}

	/**
	 * 移除空的目录
	 * 
	 * @param dirFile
	 */
	public static void removeEmptyDir(File dirFile) {
		// 文件的上级目录
		String fs[] = dirFile.list();
		if (fs == null || fs.length < 1) {
			String filePath = dirFile.getAbsolutePath();
			Boolean delRs = dirFile.delete();
			if (delRs) {
				Configs.sysLog.info("Dir is delete suc:" + filePath);
			} else {
				Configs.sysLog.info("Dir is delete fail:" + filePath);
			}
		}
	}

	/**
	 * 移除今天之前创建的空目录
	 * @param dirFile
	 */
	public static void removeBeforeTodayEmptyDir(File dirFile) {
		// 文件的上级目录
		String fs[] = dirFile.list();
		if (fs == null || fs.length < 1) {
			DateFormat df = new SimpleDateFormat("yyyyMMdd");
			Calendar ca = Calendar.getInstance();
			ca.setTimeInMillis(dirFile.lastModified());
			String fileDay = df.format(ca.getTime());
			String curDay = df.format(new Date());
			if (!fileDay.equals(curDay)) {
				String filePath = dirFile.getAbsolutePath();
				// 不是同一天
				Boolean delRs = dirFile.delete();
				if (delRs) {
					Configs.sysLog.info("Dir is delete suc:" + filePath);
				} else {
					Configs.sysLog.info("Dir is delete fail:" + filePath);
				}
			}
		}
	}


	/**
	 * 移除今天之前创建的空目录
	 * @param dirFilePath 文件夹目录
	 */
	public static void removeBeforeTodayEmptyDir(String dirFilePath) {
		// 文件的上级目录
		if(TextUtils.isEmpty(dirFilePath)) {
			Configs.sysLog.warn("the dirFilePath is null");
			return;
		}
		File dir = new File(dirFilePath);
		if(!dir.exists() || !dir.isDirectory()) {
			Configs.sysLog.warn("this dirFilePath not exists or not dir \tdirFilePath:" + dirFilePath);
			return;
		}

		File[] childFiles = dir.listFiles();
		if(childFiles == null || childFiles.length == 0) {
			Configs.sysLog.warn("this dirFilePath is a empty dir \tdirFilePath:" + dirFilePath);
			return;
		}

		for (File childFile : childFiles) {
			if(childFile != null && childFile.isDirectory()) {
				removeBeforeTodayEmptyDirImpl(childFile.getAbsolutePath());
			}
		}

	}


	/**
	 * 移除今天之前创建的空目录
	 * @param dirFilePath 文件夹目录
	 */
	public static void removeBeforeTodayEmptyDirImpl(String dirFilePath) {
		// 文件的上级目录
		if(TextUtils.isEmpty(dirFilePath)) {
			Configs.sysLog.warn("the dirFilePath is null");
			return;
		}
		File dir = new File(dirFilePath);
		if(!dir.exists() || !dir.isDirectory()) {
			Configs.sysLog.warn("this dirFilePath not exists or not dir \tdirFilePath:" + dirFilePath);
			return;
		}

		File[] childFiles = dir.listFiles();
		DateFormat df = new SimpleDateFormat("yyyyMMdd");
		Calendar ca = Calendar.getInstance();
		ca.setTimeInMillis(dir.lastModified());
		String fileDay = df.format(ca.getTime());
		String curDay = df.format(new Date());

		if(fileDay.equals(curDay)) {
//			Configs.sysLog.info("is today create");
			return;
		}

		if(null == childFiles || childFiles.length == 0) {
			// 不是同一天
			if (dir.delete()) {
				Configs.sysLog.info("Dir is delete suc:" + dirFilePath);
			} else {
				Configs.sysLog.info("Dir is delete fail:" + dirFilePath);
			}
			return;
		}

		for (File childFile : childFiles) {
			if(childFile != null && childFile.isDirectory()) {
				removeBeforeTodayEmptyDirImpl(childFile.getAbsolutePath());
			}
		}

	}

	/**
	 * 检测备份目录并返回 备份目标 文件(路径)
	 * 
	 * @param dcomFile
	 * @return
	 */
	public static String touchBackDir(File dcomFile) {
		String targetFile = dcomFile.getAbsolutePath();
		// 去监控目录
		targetFile = targetFile.replace(Configs.monitorDir, "");
		//备份文件绝对路径
		targetFile = Configs.monitorBackDir + targetFile;
		String targetFileDirStr = targetFile.substring(0, targetFile.lastIndexOf(File.separator));
		Configs.sysLog.info("64-----64-----备份文件：" + targetFile + "/r/n 目录名称:" + targetFileDirStr);
		// 备份文件夹
		File targetFileDir = new File(targetFileDirStr);
		if (!targetFileDir.exists()) {
			Boolean cr = targetFileDir.mkdirs();
			if (cr) {
				Configs.sysLog.info("Create backup dir :" + targetFileDir.getAbsolutePath());
			} else {
				Configs.sysLog.info("Create backup dir failed :" + targetFileDir.getAbsolutePath());
			}
		}
		return targetFile;
	}
	/**
	 * 检测备份目录无创建并返回 重试目标 文件(路径)
	 *
	 * @param dcomFile
	 * @return
	 */
	public static String touchRetryDir(File dcomFile) {
		String targetFile = dcomFile.getAbsolutePath();
		targetFile = targetFile.replace(Configs.monitorDir, "");
		targetFile = Configs.monitorRetryDir + targetFile;
		String targetFileDirStr = targetFile.substring(0, targetFile.lastIndexOf(File.separator));
		Configs.sysLog.info("11-----11-----重试文件：" + targetFile + "/r/n 目录名称:" + targetFileDirStr);
		File targetFileDir = new File(targetFileDirStr);
		if (!targetFileDir.exists()) {
			System.out.println("------------------------------------------------------------------------------------------");
			Boolean cr = targetFileDir.mkdirs();
			if (cr) {
				Configs.sysLog.info("Create backup dir :" + targetFileDir.getAbsolutePath());
			} else {
				Configs.sysLog.info("Create backup dir failed :" + targetFileDir.getAbsolutePath());
			}
		}
		return targetFile;
	}
	/**
	 * 检测备份目录无创建并返回 错误目标 文件(路径)
	 *
	 * @param dcomFile
	 * @return
	 */
	public static String touchEorrDir(File dcomFile) {
		String targetFile = dcomFile.getAbsolutePath();
		targetFile = targetFile.replace(Configs.monitorRetryDir, "");
		targetFile = Configs.errorDir + targetFile;
		String targetFileDirStr = targetFile.substring(0, targetFile.lastIndexOf(File.separator));
		Configs.sysLog.info("33-----33-----错误文件：" + targetFile + "/r/n 目录名称:" + targetFileDirStr);
		File targetFileDir = new File(targetFileDirStr);
		if (!targetFileDir.exists()) {
			System.out.println("@------------------------------------------------------------------------------------------");
			Boolean cr = targetFileDir.mkdirs();
			if (cr) {
				Configs.sysLog.info("Create backup dir :" + targetFileDir.getAbsolutePath());
			} else {
				Configs.sysLog.info("Create backup dir failed :" + targetFileDir.getAbsolutePath());
			}
		}
		return targetFile;
	}

	/**
	 * 获取备份文件路径
	 * @param sourceFilePath
	 * @return
	 */
	public static String getBackupPath(String sourceFilePath) {
		if(TextUtils.isEmpty(sourceFilePath)) {
			return null;
		}
		String targetFilePath = sourceFilePath.replace(Configs.monitorDir, "");
		targetFilePath = targetFilePath.replace(Configs.monitorRetryDir, "");

		//备份文件绝对路径
		targetFilePath = Configs.monitorBackDir + targetFilePath;
		String targetFileDirPath = targetFilePath.substring(0, targetFilePath.lastIndexOf(File.separator));
		Configs.sysLog.info("备份文件：" + targetFilePath + "/r/n 目录名称:" + targetFileDirPath);

		// 备份文件夹
		touchDir(targetFileDirPath);
		return targetFilePath;
	}

	/**
	 * 获取重试文件路径
	 * @param sourceFilePath
	 * @return
	 */
	public static String getRetryFilePath(String sourceFilePath) {
		if(TextUtils.isEmpty(sourceFilePath)) {
			return null;
		}
		String targetFilePath = sourceFilePath.replace(Configs.monitorDir, "");

		//重试文件绝对路径
		targetFilePath = Configs.monitorRetryDir + targetFilePath;
		String targetFileDirPath = targetFilePath.substring(0, targetFilePath.lastIndexOf(File.separator));
		Configs.sysLog.info("重试文件：" + targetFilePath + "/r/n 目录名称:" + targetFileDirPath);

		// 备份文件夹
		touchDir(targetFileDirPath);
		return targetFilePath;
	}

	/**
	 * 获取错误文件路径
	 * @param sourceFilePath
	 * @return
	 */
	public static String getErrorPath(String sourceFilePath) {
		if(TextUtils.isEmpty(sourceFilePath)) {
			return null;
		}
		String targetFilePath = sourceFilePath.replace(Configs.monitorRetryDir, "");

		//备份文件绝对路径
		targetFilePath = Configs.errorDir + targetFilePath;
		String targetFileDirPath = targetFilePath.substring(0, targetFilePath.lastIndexOf(File.separator));
		Configs.sysLog.info("错误文件：" + targetFilePath + "/r/n 目录名称:" + targetFileDirPath);

		// 备份文件夹
		touchDir(targetFileDirPath);
		return targetFilePath;
	}

	/**
	 * 创建文件夹
	 * @param dirPath
	 */
	public static void touchDir(String dirPath){
		File dir = new File(dirPath);
		if(!dir.exists()) {
			boolean flag = dir.mkdirs();
			if(flag) {
				Configs.sysLog.info("Create dir :" + dir.getAbsolutePath());
			} else {
				Configs.sysLog.info("Create dir failed :" + dir.getAbsolutePath());
			}
		}
	}
}
